summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNadia Barbosa <nadiabarbosa@me.com>2017-03-03 18:09:39 -0800
committerNadia Barbosa <captainbarbosa@users.noreply.github.com>2017-03-03 18:59:30 -0800
commit9ea41136345c919ba06f31a940ff7a23caabfb08 (patch)
treed75069c27ca51c964dc8bf08b029d4175a7730fc
parent4d058ffd94a07c1e1fe48814f29a16a1c5f8a0fd (diff)
downloadqtlocation-mapboxgl-9ea41136345c919ba06f31a940ff7a23caabfb08.tar.gz
[ios] Clarify docs for MGLUserTrackingMode
-rw-r--r--platform/ios/src/MGLMapView.h25
1 files changed, 22 insertions, 3 deletions
diff --git a/platform/ios/src/MGLMapView.h b/platform/ios/src/MGLMapView.h
index bdb6d2c917..5d6daf74c5 100644
--- a/platform/ios/src/MGLMapView.h
+++ b/platform/ios/src/MGLMapView.h
@@ -51,11 +51,30 @@ typedef NS_ENUM(NSUInteger, MGLAnnotationVerticalAlignment) {
typedef NS_ENUM(NSUInteger, MGLUserTrackingMode) {
/** The map does not follow the user location. */
MGLUserTrackingModeNone = 0,
- /** The map follows the user location. */
+ /** The map follows the user location. This tracking mode falls back
+ to `MGLUserTrackingModeNone` if the user pans the map view. */
MGLUserTrackingModeFollow,
- /** The map follows the user location and rotates when the heading changes. */
+ /**
+ The map follows the user location and rotates when the heading changes.
+ The default user location annotation displays a fan-shaped indicator with
+ the current heading. The heading indicator represents the direction the
+ device is facing, which is sized according to the reported accuracy.
+
+ This tracking mode is disabled if the user pans the map view, but
+ remains enabled if the user zooms in. If the user rotates the map
+ view, this tracking mode will fall back to `MGLUserTrackingModeFollow`.
+ */
MGLUserTrackingModeFollowWithHeading,
- /** The map follows the user location and rotates when the course changes. */
+ /**
+ The map follows the user location and rotates when the course changes.
+ Course represents the direction in which the device is traveling.
+ The default user location annotation shows a puck-shaped indicator
+ that rotates as the course changes.
+
+ This tracking mode is disabled if the user pans the map view, but
+ remains enabled if the user zooms in. If the user rotates the map view,
+ this tracking mode will fall back to `MGLUserTrackingModeFollow`.
+ */
MGLUserTrackingModeFollowWithCourse,
};